=======
Credits
=======

Development Lead
----------------

* Grant McConnaughey <grantmcconnaughey@gmail.com>

Contributors
------------

* Boris Shifrin <https://github.com/ramusus>
* Matheus Cansian <https://github.com/mscansian>

Background
----------

The ``FieldHistoryTracker`` class in this project is based off of the ``FieldTracker`` class from `django-model-utils <https://github.com/carljm/django-model-utils>`_. The following authors contributed to ``FieldTracker``:

* Trey Hunner
* Matthew Schinckel
* Mikhail Silonov
* Carl Meyer
* @bboogaard
